﻿using System.Diagnostics;
using PdfSharp.Drawing;
using PdfSharp.Fonts;
using PdfSharp.Pdf;

namespace EZFontResolver1
{
    class Program
    {
        static void Main()
        {
            // Get the EZFontResolver.
            EZFontResolver fontResolver = EZFontResolver.Get;
            // Assign it to PDFsharp.
            GlobalFontSettings.FontResolver = fontResolver;

            // We only have Janitor Regular, no Bold, no Italic.
            // We allow PDFsharp to simulate Bold and Italic for us.
            fontResolver.AddFont("Janitor", XFontStyle.Regular,
                @"..\..\..\fonts\janitor\janitor.ttf", true, true);

            // The Ubuntu family has many font faces, so we do not need simulation here.
            fontResolver.AddFont("Ubuntu", XFontStyle.Regular,
                @"..\..\..\fonts\ubuntufontfamily0.80\ubuntu-R.ttf");
            fontResolver.AddFont("Ubuntu", XFontStyle.Italic,
                @"..\..\..\fonts\ubuntufontfamily0.80\ubuntu-RI.ttf");
            fontResolver.AddFont("Ubuntu", XFontStyle.Bold,
                @"..\..\..\fonts\ubuntufontfamily0.80\ubuntu-B.ttf");
            fontResolver.AddFont("Ubuntu", XFontStyle.BoldItalic,
                @"..\..\..\fonts\ubuntufontfamily0.80\ubuntu-BI.ttf");

            // Now we can use "Janitor" and "Ubuntu" like we use installed fonts.
            var document = new PdfDocument();
            var page = document.AddPage();
            var gfx = XGraphics.FromPdfPage(page);

            XFont janReg = new XFont("Janitor", 20, XFontStyle.Regular);
            XFont janBold = new XFont("Janitor", 20, XFontStyle.Bold);
            XFont janItalic = new XFont("Janitor", 20, XFontStyle.Italic);
            XFont janBoldItalic = new XFont("Janitor", 20, XFontStyle.BoldItalic);

            // Draw the text
            gfx.DrawString("Hello, World!", janReg, XBrushes.Black,
              new XRect(0, 0, page.Width, 20),
              XStringFormats.Center);
            gfx.DrawString("Hello, World!", janBold, XBrushes.Black,
              new XRect(0, 20, page.Width, 20),
              XStringFormats.Center);
            gfx.DrawString("Hello, World!", janItalic, XBrushes.Black,
              new XRect(0, 40, page.Width, 20),
              XStringFormats.Center);
            gfx.DrawString("Hello, World!", janBoldItalic, XBrushes.Black,
              new XRect(0, 60, page.Width, 20),
              XStringFormats.Center);

            XFont ubReg = new XFont("Ubuntu", 20, XFontStyle.Regular);
            XFont ubBold = new XFont("Ubuntu", 20, XFontStyle.Bold);
            XFont ubItalic = new XFont("Ubuntu", 20, XFontStyle.Italic);
            XFont ubBoldItalic = new XFont("Ubuntu", 20, XFontStyle.BoldItalic);

            // Draw the text
            gfx.DrawString("Hello, World!", ubReg, XBrushes.Black,
              new XRect(0, 100, page.Width, 20),
              XStringFormats.Center);
            gfx.DrawString("Hello, World!", ubBold, XBrushes.Black,
              new XRect(0, 120, page.Width, 20),
              XStringFormats.Center);
            gfx.DrawString("Hello, World!", ubItalic, XBrushes.Black,
              new XRect(0, 140, page.Width, 20),
              XStringFormats.Center);
            gfx.DrawString("Hello, World!", ubBoldItalic, XBrushes.Black,
              new XRect(0, 160, page.Width, 20),
              XStringFormats.Center);

            // Save the document...
            const string filename = "HelloWorld.pdf";
            document.Save(filename);
            // ...and start a viewer.
            Process.Start(filename);
        }
    }
}
